﻿using System.Threading.Tasks;
using System.Collections.Generic;
using System.Net.Http;
using Microsoft.Extensions.Caching.Memory;
using Website.Models.Blog;
using Robware.Lib.ApiClient;

namespace Website.Data
{
	public class BlogApi : ApiClient, IBlogApi {
		public BlogApi(HttpClient client, IMemoryCache cache, CacheDurations cacheDurations) : base(client, cache, cacheDurations) {
		}

		public async Task<BlogPost> GetPostByUrlAsync(string url, bool skipCache = false) => await Get<BlogPost>("get/" + url, skipCache: skipCache);
		public async Task<IEnumerable<BlogPost>> GetLatestPostsAsync(int count = 0, int offset = 0) => await Get<IEnumerable<BlogPost>>("getlatestposts", new{count, offset});
		public async Task<BlogPost> GetLatestPostAsync() => await Get<BlogPost>("getlatestpost");
		public async Task<int> GetCountAsync() => await Get<int>("getcount");
		public async Task<BlogPost> GetPostByIdAsync(int id, bool skipCache = false) => await Get<BlogPost>("get/" + id, skipCache: skipCache);
		public async Task<BlogPost> SavePost(BlogPostSubmission post) => await Post<BlogPost>("savepost", post);
		public async Task<IEnumerable<BlogPost>> GetAllPostsAsync(bool skipCache = false) => await Get<IEnumerable<BlogPost>>("getallposts", skipCache: skipCache);
		public async Task DeletePostAsync(int id) => await Post<object>("deletepost", id);
		public async Task PublishPostAsync(int id) => await Post<object>("publishpost", id);
	}
}
